==> deepin-installer-reborn_2.2.15.2.orig.tar.xz: deepin-installer-reborn-2.2.15.2/i18n/oem-zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>OemSettingsItemView</name>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="81"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="83"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="85"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="88"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="90"/>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="229"/>
        <source>Default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="92"/>
        <source>Current value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="94"/>
        <source>Use default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="97"/>
        <source>Custom value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OemWindow</name>
    <message>
        <location filename="../src/oem/oem_window.cpp" line="45"/>
        <source>Failed to create $HOME/oem folder or sub-folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/oem_window.cpp" line="53"/>
        <source>Failed to load model data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-installer-reborn_2.7.14.orig.tar.xz: deepin-installer-reborn-2.7.14/i18n/oem-zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>installer::OemSettingsItemView</name>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="81"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="83"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="85"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="88"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="90"/>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="229"/>
        <source>Default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="92"/>
        <source>Current value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="94"/>
        <source>Use default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/views/oem_settings_item_view.cpp" line="97"/>
        <source>Custom value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>installer::OemWindow</name>
    <message>
        <location filename="../src/oem/oem_window.cpp" line="45"/>
        <source>Failed to create $HOME/oem folder or sub-folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/oem/oem_window.cpp" line="53"/>
        <source>Failed to load model data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
